@@ -2,5 +2,5 @@ print.LMmanifest <-function(x,...){
 cat("Call:\n")
 print(x$call)
 cat("\nConvergence info:\n")
-print(cbind(LogLik=x$lk,np=x$npa,AIC=x$aic, BIC=x$bic))
+print(cbind(LogLik=x$lk,np=x$np,AIC=x$aic, BIC=x$bic))
 }
\ No newline at end of file
